@@ -1,5 +1,5 @@
 `rcounts` <-
-function(N, margins, mu, phi, omega, psi, corstr, corpar, conv=0.01) {
+function(N, margins, mu, phi=rep(NA,length(margins)), omega=rep(NA,length(margins)), psi=rep(NA,length(margins)), corstr, corpar, conv=0.01) {
   error <- F
   dimension <- length(margins)
   if (corstr=="ex") {
